@@ -174,6 +174,22 @@ ip6tables_wrapper(){
     cmd_wrapper ip6tables ${IP6TABLES_BINARY} "$@"
 }
 
+verify_iptables()
+{
+    local ret
+    ret=0
+
+    if [ -z "$IPTABLES_BINARY" ]; then
+        sqm_error "No iptables binary found, please install 'iptables' or 'iptables-nft' to use this script"
+        ret=1
+    fi
+    if [ -z "$IP6TABLES_BINARY" ]; then
+        sqm_error "No ip6tables binary found, please install 'ip6tables' or 'ip6tables-nft' to use this script"
+        ret=1
+    fi
+    return $ret
+}
+
 # wrapper to call tc to allow debug logging
 tc_wrapper(){
     cmd_wrapper tc ${TC_BINARY} "$@"
@@ -263,7 +279,7 @@ check_state_dir() {
 
     # OpenWrt doesn't have stat; for now just skip the remaining tests if it's
     # not available
-    which stat >/dev/null 2>&1 || return 0
+    command -v stat >/dev/null 2>&1 || return 0
 
     PERM="0$(stat -L -c '%a' "${SQM_STATE_DIR}")"
     if [ "$((PERM & 0002))" -ne 0 ]; then
